@@ -12,7 +12,7 @@ class Node():
   # This methods prints the network structure of our network when the class gets called
   def __call__(self): 
     for obj in gc.get_objects():
-      if isinstance(obj, self.linearLayer):
+      if isinstance(obj, self.LinearLayer):
         print('[' + str(obj) + ", num_inputs: " + str(obj.num_inputs) + " num_neurons:"  + str(obj.num_neurons) + '],')
 
 
